package com.care.bigscreen.controller;


import com.care.bigscreen.service.StStationService;
import com.care.bigscreen.vo.BigScreenStatisticsVO;

import com.care.util.Result;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;


/**
 * @author javadoc
 * @version 1.0
 * @description 系统设置-字典管理模块-前端控制器
 * @date
 */
@Slf4j
@RestController
@RequestMapping("/bms/system/dictionaries")
public class StStationController {

    @Autowired
    private StStationService stStationService;


    /**
     * 运营商大屏统计查询
     */
    @ApiOperation(value = "运营商大屏统计查询", notes = "运营商大屏统计查询")
    @GetMapping("/selectBigScreenStatisticsByOp")

    public Result<BigScreenStatisticsVO> selectBigScreenStatisticsByOp() {
        try {
            BigScreenStatisticsVO bigScreenStatisticsVO =  stStationService.selectBigScreenStatistics(null,null);
            return Result.success(bigScreenStatisticsVO);
        } catch (Exception e) {
           log.error("运营商大屏统计查询出现异常",e);
            return Result.error("系统错误，运营商大屏统计查询失败");
        }
    }

    /**
     * 机构大屏统计查询
     */
    @ApiOperation(value = "机构大屏统计查询", notes = "机构大屏统计查询")
    @GetMapping("/selectBigScreenStatisticsByOrg")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(name = "orgId", value = "机构ID", dataTypeClass = Long.class)
            }
    )
    public Result<BigScreenStatisticsVO> selectBigScreenStatisticsByOrg(Long orgId) {
        try {
            BigScreenStatisticsVO bigScreenStatisticsVO =  stStationService.selectBigScreenStatistics(null,orgId);
            return Result.success(bigScreenStatisticsVO);
        } catch (Exception e) {
            log.error("机构大屏统计查询异常",e);
            return Result.error("系统错误，机构大屏统计查询失败");
        }
    }

    /**
     * 站点统计查询
     */
    @ApiOperation(value = "站点统计查询", notes = "站点统计查询")
    @GetMapping("/selectBigScreenStatisticsByStation")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(name = "stationId", value = "站点ID", dataTypeClass = Long.class)
            }
    )
    public Result<BigScreenStatisticsVO> selectBigScreenStatisticsByStation(Long stationId) {
        try {
            List<Long> stationIds = new ArrayList<>();
            stationIds.add(stationId);
            BigScreenStatisticsVO bigScreenStatisticsVO =  stStationService.selectBigScreenStatistics(stationIds,null);
            return Result.success(bigScreenStatisticsVO);
        } catch (Exception e) {
            log.error("站点统计查询出现异常",e);
            return Result.error("系统错误，站点统计查询失败");
        }
    }


}
